@@ -1,5 +1,5 @@
 #!/usr/bin/env bash
-# Copyright (C) 2023 The Qt Company Ltd.
+# Copyright (C) 2022 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 set -ex
@@ -16,15 +16,14 @@ installPackages+=(ca-certificates)
 installPackages+=(git)
 installPackages+=(zlib-devel)
 installPackages+=(glib2-devel)
-installPackages+=(openssl-devel)
+installPackages+=(openssl3)
+installPackages+=(openssl3-devel)
 installPackages+=(freetype-devel)
 installPackages+=(fontconfig-devel)
 installPackages+=(curl-devel)
 installPackages+=(expat-devel)
 installPackages+=(gettext-devel)
 installPackages+=(perl-devel)
-# Required by some old pkg perl script, FindBin.pm was moved to new package in perl 5.32
-installPackages+=(perl-FindBin)
 installPackages+=(dh-autoreconf)
 # cmake build
 installPackages+=(ninja-build)
@@ -33,24 +32,8 @@ installPackages+=(double-conversion-devel)
 installPackages+=(zstd)
 installPackages+=(libzstd-devel)
 # EGL support
-# mesa-libEGL-devel need to use older version than 22.1.5-2.el9 which cause Xorg to crash
-#installPackages+=(mesa-libEGL-devel-21.3.4-2.el9)
-#installPackages+=(mesa-libGL-devel-21.3.4-2.el9)
-
-# Using same mesa libraries for RHEL 9.2 which also RHEL 8.8 had due to Xorg crash issue:
-#installPackages+=(mesa-libEGL-devel-21.3.4-1.el9.x86_64)
-#installPackages+=(mesa-libGL-devel-21.3.4-1.el9.x86_64)
-#installPackages+=(mesa-dri-drivers-21.3.4-1.el9.x86_64)
-#installPackages+=(mesa-libgbm-21.3.4-1.el9.x86_64)
-#installPackages+=(mesa-vulkan-drivers-21.3.4-1.el9.x86_64)
-
-# Same as lines above but with -2 version which should be found for el9
-installPackages+=(mesa-libEGL-devel-21.3.4-2.el9.x86_64)
-installPackages+=(mesa-libGL-devel-21.3.4-2.el9.x86_64)
-installPackages+=(mesa-dri-drivers-21.3.4-2.el9.x86_64)
-installPackages+=(mesa-libgbm-21.3.4-2.el9.x86_64)
-installPackages+=(mesa-vulkan-drivers-21.3.4-2.el9.x86_64)
-
+installPackages+=(mesa-libEGL-devel)
+installPackages+=(mesa-libGL-devel)
 installPackages+=(libxkbfile-devel)
 # Xinput2
 installPackages+=(libXi-devel)
@@ -65,24 +48,23 @@ installPackages+=(dbus-devel)
 installPackages+=(gstreamer1-plugins-bad-free)
 installPackages+=(gstreamer1-devel)
 installPackages+=(gstreamer1-plugins-base-devel)
-installPackages+=(gstreamer1-plugin-openh264)
-# pipewire for QtMultimedia
-installPackages+=(pipewire-devel)
-# yasm for QtMultimedia
+# for QtMultimedia, ffmpeg
 installPackages+=(yasm)
+installPackages+=(libva-devel)
 # gtk3 style for QtGui/QStyle
 installPackages+=(gtk3-devel)
 # libusb1 for tqtc-boot2qt/qdb
 installPackages+=(libusbx-devel)
-# speech-dispatcher-devel / flite-devel for QtSpeech
+# speech-dispatcher-devel for QtSpeech, otherwise it has no backend on Linux
 installPackages+=(speech-dispatcher-devel)
-installPackages+=(flite-devel)
 # Python 2 devel and pip. python-pip requires the EPEL repository to be added
-# Python 2 no longer supported
-# installPackages+=(python2-devel python2-pip)
+installPackages+=(python2-devel python2-pip)
 # Python 3 with python-devel, pip and virtualenv
-installPackages+=(python3)
-installPackages+=(python3-devel)
+installPackages+=(python36)
+installPackages+=(python36-devel)
+# Python 3.8 for pyside. Qt for Python support for Python 3.6 will be deprecated in within pyside6.3
+installPackages+=(python38)
+installPackages+=(python38-devel)
 # WebEngine
 installPackages+=(bison)
 installPackages+=(flex)
@@ -97,10 +79,9 @@ installPackages+=(libxshmfence-devel)
 installPackages+=(nspr-devel)
 installPackages+=(nss-devel)
 installPackages+=(python3-html5lib)
-installPackages+=(libstdc++-static)
-installPackages+=(mesa-libgbm-devel-21.3.4-2.el9.x86_64)
+installPackages+=(mesa-libgbm-devel)
 # For Android builds
-installPackages+=(java-17-openjdk-devel-17.0.9.0.9)
+installPackages+=(java-11-openjdk-devel)
 # For receiving shasum
 installPackages+=(perl-Digest-SHA)
 # INTEGRITY requirements
@@ -115,9 +96,8 @@ installPackages+=(libxslt-devel)
 # For building Wayland from source
 installPackages+=(libffi-devel)
 # QtWayland
-# installPackages+=(mesa-libwayland-egl)
-# installPackages+=(mesa-libwayland-egl-devel)
-installPackages+=(libwayland-egl)
+installPackages+=(mesa-libwayland-egl)
+installPackages+=(mesa-libwayland-egl-devel)
 installPackages+=(libwayland-client)
 installPackages+=(libwayland-cursor)
 installPackages+=(libwayland-server)
@@ -152,30 +132,14 @@ installPackages+=(perl-Data-Dumper)
 installPackages+=(gcc)
 installPackages+=(gcc-c++)
 installPackages+=(make)
-installPackages+=(gcc-toolset-12)
 # Open source VMware Tools
 installPackages+=(open-vm-tools)
-# nfs-utils is needed to make mount work with ci-files01
-installPackages+=(nfs-utils)
-# cifs-utils, for mounting smb drive
-installPackages+=(keyutils)
-installPackages+=(cifs-utils)
-# zip, needed for vcpkg caching
-installPackages+=(zip)
-# OpenSSL requirement, built by vcpkg
-installPackages+=(perl-IPC-Cmd)
-# password management support for Qt Creator
-installPackages+=(libsecret-devel)
-# for license-service library
-installPackages+=(libuuid-devel)
-# For Firebird in RTA
-installPackages+=(libtommath-devel)
 
 sudo yum -y install "${installPackages[@]}"
 
-sudo dnf install nodejs-16.14.0-4.el9_0 -y
-# Required by QtCore
-sudo dnf install 'perl(English)' -y
+sudo ln -s /usr/bin/python2 /usr/bin/python
+
+sudo dnf -y module install nodejs:12
 
 # We shouldn't use yum to install virtualenv. The one found from package repo is not
 # working, but we can use installed pip
@@ -186,20 +150,9 @@ sudo pip config --user set global.extra-index-url https://pypi.org/simple/
 
 sudo pip3 install virtualenv wheel
 # Just make sure we have virtualenv to run with python3.8 -m virtualenv
-sudo python -m pip install virtualenv wheel
-sudo python -m pip install -r "${BASH_SOURCE%/*}/../common/shared/requirements.txt"
+sudo python3.8 -m pip install virtualenv wheel
 
 sudo /usr/bin/pip3 install wheel
-sudo /usr/bin/pip3 install -r "${BASH_SOURCE%/*}/../common/shared/requirements.txt"
-
-# Provisioning during installation says:
-# 'The script sbom2doc is installed in '/usr/local/bin' which is not on PATH.'
-# hence the explicit assignment to SBOM_PYTHON_APPS_PATH.
-source "${BASH_SOURCE%/*}/../common/unix/SetEnvVar.sh"
-SetEnvVar "SBOM_PYTHON_APPS_PATH" "/usr/local/bin"
-
-# Make FindPython3.cmake to find python3
-sudo ln -s /usr/bin/python3 /usr/local/bin/python3
 
 gccVersion="$(gcc --version |grep -Eo '[0-9]+\.[0-9]+(\.[0-9]+)?' |head -n 1)"
 echo "GCC = $gccVersion" >> versions.txt
@@ -207,8 +160,5 @@ echo "GCC = $gccVersion" >> versions.txt
 glibcVersion="$(ldd --version |grep -Eo '[0-9]+\.[0-9]+(\.[0-9]+)?' |head -n 1)"
 echo "glibc = $glibcVersion" >> versions.txt
 
-OpenSSLVersion="$(openssl version |cut -b 9-14)"
-echo "System's OpenSSL = $OpenSSLVersion" >> ~/versions.txt
-
-# List all available updates
-sudo yum -y list updates
+OpenSSLVersion="$(openssl3 version |cut -b 9-14)"
+echo "OpenSSL = $OpenSSLVersion" >> ~/versions.txt
